@@ -1,13 +1,19 @@
 package Progress::Any::Output;
 
+our $DATE = '2015-01-26'; # DATE
+our $VERSION = '0.05'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.04'; # VERSION
-
 require Progress::Any;
 
+sub import {
+    my $self = shift;
+    __PACKAGE__->set(@_) if @_;
+}
+
 sub _set_or_add {
     my $class = shift;
     my $which = shift;
@@ -67,7 +73,7 @@ Progress::Any::Output - Assign output to progress indicators
 
 =head1 VERSION
 
-This document describes version 0.04 of Progress::Any::Output (from Perl distribution Progress-Any-Output), released on 2014-10-14.
+This document describes version 0.05 of Progress::Any::Output (from Perl distribution Progress-Any-Output), released on 2015-01-26.
 
 =head1 SYNOPSIS
 
@@ -76,15 +82,25 @@ In your application:
  use Progress::Any::Output;
  Progress::Any::Output->set('TermProgressBarColor');
 
+or:
+
+ use Progress::Any::Output 'TermProgressBarColor';
+
 To give parameters to output:
 
+ use Progress::Any::Output;
  Progress::Any::Output->set('TermProgressBarColor', width=>50, ...);
 
+or:
+
+ use Progress::Any::Output 'TermProgressBarColor', width=>50, ...;
+
 To assign output to a certain (sub)task:
 
+ use Progress::Any::Output;
  Progress::Any::Output->set({task=>'main.download'}, 'TermMessage');
 
-To add additional output, use add() instead of set().
+To add additional output, use C<add()> instead of C<set()>.
 
 =head1 DESCRIPTION
 
@@ -133,7 +149,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
